4Suite API Documentation: Ft.Lib.CommandLine.CommandLineTestUtil

4Suite™ API Documentation

# ► Module Ft.Lib.CommandLine.CommandLineTestUtil

Command-line script related extensions to the test suite framework

    Copyright 2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: Test, TestRun

## Classes

class Test

  ### Methods

  __init__(self, commandName, runs)
  test(self, tester)
class TestRun

  ### Methods

  __init__(self, name, options, args, expectedOut=None, validationFunc=None, input=None, outFile=None, skipOutputTest=False, compareFunc=<built-in function cmp>)
  makeCommandLine(self, options, args)
  test(self, tester, script)